## [1.5.0] - 2024-06-03
- [COMPAT] No more support for Python 3.7 and 3.8 (see MR !99)
- [COMPAT] Support for Python 3.10 and 3.11 (see MR !99 and !121)
- [DOC] New glossary page added to the documentation (see MR !95)
- [REF] Refactoring of Samplers (see MR !93)
- [REF] Refactoring of Noise Models (see MR !91)
- [REF] Refactoring of the Univariate Model (see MR !89)
- [REF] Refactoring to decouple Algorithms and Models (see MR !90)
- [REF] Refactoring of Realizations (see MR !92)
